package com.persagy.proxy.adm.constant;

import java.util.HashMap;
import java.util.Map;

import cn.hutool.core.util.StrUtil;

/**
 * 对象类型的前缀与全名的来回映射，以及根据边类型获取对应的对象类型前缀
 * 
 * @version 1.0.0
 * @company persagy 
 * @author zhangqiankun
 * @date 2021年9月3日 下午9:16:10
 */
public class ObjTypeMapping {

	/** example: Sp -> space */
	public static final Map<String, String> PREFIX_FULLNAME = new HashMap<String, String>();
	
	/** example: space -> Sp */
	public static final Map<String, String> FULLNAME_PREFIX = new HashMap<String, String>();
	
	static {
	    
		PREFIX_FULLNAME.put("Pj", "project");
		PREFIX_FULLNAME.put("Bd", "building");
		PREFIX_FULLNAME.put("Fl", "floor");
		PREFIX_FULLNAME.put("Sp", "space");
		PREFIX_FULLNAME.put("Sy", "system");
		PREFIX_FULLNAME.put("Eq", "equipment");
		PREFIX_FULLNAME.put("Sh", "shaft");
		PREFIX_FULLNAME.put("Ec", "component");
		PREFIX_FULLNAME.put("Pe", "property");
		
		FULLNAME_PREFIX.put("project", "Pj");
		FULLNAME_PREFIX.put("building", "Bd");
		FULLNAME_PREFIX.put("floor", "Fl");
		FULLNAME_PREFIX.put("space", "Sp");
		FULLNAME_PREFIX.put("system", "Sy");
		FULLNAME_PREFIX.put("equipment", "Eq");
		FULLNAME_PREFIX.put("shaft", "Sh");
		FULLNAME_PREFIX.put("component", "Ec");
		FULLNAME_PREFIX.put("property", "Pe");
		
	}
	
	/**
	 * 获取中台中，边类型编码的前两位
	 * 
	 * @param relCode 最低2位，不然抛异常
	 * @return 空字符串或者对应前缀
	 */
	public static String getRelCodePrefix(String relCode) {
		return StrUtil.isBlank(relCode) ? AdmCommonConstant.EMPTY : relCode.substring(0, 2);
	}
	
	/**
	 * 获取中台中对象类型的前两位
	 * 
	 * @param objType 最低5位，不然抛异常
	 * @return 空字符串或者对应后缀
	 */
	public static String getRelCodeSuffix(String relCode) {
		return StrUtil.isBlank(relCode) ? AdmCommonConstant.EMPTY : relCode.substring(3, 5);
	}
	
}
